=========
pydnameth
=========


.. image:: https://img.shields.io/pypi/v/pydnameth.svg
        :target: https://pypi.python.org/pypi/pydnameth

.. image:: https://img.shields.io/travis/AaronBlare/pydnameth.svg
        :target: https://travis-ci.org/AaronBlare/pydnameth

.. image:: https://readthedocs.org/projects/pydnameth/badge/?version=latest
        :target: https://pydnameth.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://badges.gitter.im/AaronBlare/pydnameth.png
        :target: https://gitter.im/pydnameth/community
        :alt: Project Chat

.. image:: https://pyup.io/repos/github/AaronBlare/pydnameth/shield.svg
     :target: https://pyup.io/repos/github/AaronBlare/pydnameth/
     :alt: Updates


DNA Methylation Analysis Package


* Free software: MIT license
* Documentation: https://pydnameth.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
